==> ofdlib2-0.9.7.tar.gz: ofdlib2-0.9.7/ofdlib2/coefficients.h <==
static const double a7c[4] = {0.,  0.79927407388837191000,
	 	 	      -0.18941925911069757000,
      			      0.02652148144434106700};

static const double a7d[4][8] = {{0.},
			         {0., -2.225833963270, 4.827779580575,
			          -5.001388453836, 3.911103941646,
			          -2.115267458633, 0.718882784412,
			          -0.115276430895},
			         {0., -0.212932721951, -1.060320390770,
			          2.078926116439, -1.287179452384,
			          0.685176395471, -0.245320613994,
			          0.041650667189},
			         {0., 0.048264094108, -0.488255830845,
			          -0.366015590723, 1.048005455857,
			          -0.289325926394, 0.050392437692,
			          -0.003064639693}};

static const double a11c[6] = {0., 0.872756993962667, -0.286511173973333,
	  		       9.032000128000002e-002, -2.077940582400000e-002,
    		               2.484594688000000e-003};

static const double a11d[6][12] = {{0.},
			           {0., -2.391602219538, 5.832490322294,
			            -7.650218001183, 7.907810563576,
			            -5.922599052629, 3.071037015445,
				    -1.014956769726, 0.170022256519,
				    0.002819958377, -0.004791009708,
			            -0.000013063429},
			           {0., -0.180022054228, -1.237550583044,
				    2.484731692990, -1.810320814061,
				    1.112990048440, -0.481086916514,
			            0.126598690230, -0.015510730165,
				    0.000024609059 - 0.000003,
			            0.000156447571 - 0.000000000001,
				    -0.000007390277},
			           {0., 0.057982271137, -0.536135360383,
			            -0.264089548969, 0.917445877604,
			            -0.169688364841, -0.029716326170,
				    0.029681617641, -0.005222483773,
				    -0.000118806260, -0.000118806260,
			            -0.000020069730},
			           {0., -0.013277273810, 0.115976072920,
				    -0.617479187931, -0.274113948206 + 0.000000000002,
			            1.086208764655 - 0.000000000002,
			            -0.402951626982, 0.131066986242,
				    -0.028154858354, 0.002596328316,
				    0.000128743150, 0.},
			           {0., 0.016756572303, -0.117478455239,
				    0.411034935097, -1.130286765151,
				    0.341435872100 - 0.000000000001, 0.556396830543,
				    -0.082525734207, 0.003565834658,
			            0.001173034777, -0.000071772671 + 0.000000000064,
			            -0.000000352273}};

static const double d11d[6][12] = {{0.},
				   {0., 0.320882352941, -0.465,
			            0.179117647059, -0.035},
				   {0., -0.085777408970 + 0.000000000001,
				    0.277628171524, -0.356848072173,
				    0.223119093072, -0.057347064865,
				    -0.000747264596, -0.000027453993},
				   {0., 0.0307159855992469, -0.148395705486028,
				    0.312055385963757, -0.363202245195514,
				    0.230145457063431, -0.0412316564605079,
				    -0.0531024700805787, 0.0494343261171287,
				    -0.0198143585458560, 0.00339528102492129},
				   {0., -0.000054596010, 0.042124772446,
				    -0.173103107841, 0.299615871352,
				    -0.276543612935, 0.131223506571,
				    -0.023424966418, 0.013937561779,
				    -0.024565095706, 0.013098287852,
				    -0.002308621090},
				   {0., 0.008391235145, -0.047402506444,
				    0.121438547725, -0.200063042812,
				    0.240069047836, -0.207269200140 - 0.000000000001,
				     0.122263107844 - 0.000000000001,
				     -0.047121062819, 0.009014891495,
				     0.001855812216, -0.001176830044}
				   };

static const double d11c[6] = {0.234810479761700, -0.199250131285813,
			       0.120198310245186, -0.049303775636020,
			       0.012396449873964, -0.001446093078167};

static const double d3c[2] = {0.5, -0.25};

static const double d5c[3] = {0.375, -0.25, 0.0625};

static const double d7c[4] = {0.2873928425, -0.2261469518, 0.1063035788, -0.0238530482};

static const double c_sc[4] = {0.210383, -0.210383, 0.039617, -0.039617};

static const double eps = 6e-8;

constexpr double g1 = 1.0000000000000000;
constexpr double g2 = 0.5000000000000000;
constexpr double g3 = 0.1659197713678104;
constexpr double g4 = 4.091973204095216e-2;
constexpr double g5 = 7.555704391128985e-3;
constexpr double g6 = 8.914212608018190e-4;

constexpr double r6 = g1;
constexpr double r5 = g2;
constexpr double r4 = g3/r5;
constexpr double r3 = g4/(r4*r5);
constexpr double r2 = g5/(r3*r4*r5);
constexpr double r1 = g6/(r2*r3*r4*r5);

constexpr double rk[7] = {0., r1, r2, r3, r4, r5, r6};

==> ofdlib2-0.10.0.tar.gz: ofdlib2-0.10.0/ofdlib2/coefficients.h <==
static const double a7c[4] = {0.,  0.79927407388837191000,
	 	 	      -0.18941925911069757000,
      			      0.02652148144434106700};

static const double a7d[4][8] = {{0.},
			         {0., -2.225833963270, 4.827779580575,
			          -5.001388453836, 3.911103941646,
			          -2.115267458633, 0.718882784412,
			          -0.115276430895},
			         {0., -0.212932721951, -1.060320390770,
			          2.078926116439, -1.287179452384,
			          0.685176395471, -0.245320613994,
			          0.041650667189},
			         {0., 0.048264094108, -0.488255830845,
			          -0.366015590723, 1.048005455857,
			          -0.289325926394, 0.050392437692,
			          -0.003064639693}};

static const double a11c[6] = {0., 0.872756993962667, -0.286511173973333,
	  		       9.032000128000002e-002, -2.077940582400000e-002,
    		               2.484594688000000e-003};

static const double a11d[6][12] = {{0.},
			           {0., -2.391602219538, 5.832490322294,
			            -7.650218001183, 7.907810563576,
			            -5.922599052629, 3.071037015445,
				    -1.014956769726, 0.170022256519,
				    0.002819958377, -0.004791009708,
			            -0.000013063429},
			           {0., -0.180022054228, -1.237550583044,
				    2.484731692990, -1.810320814061,
				    1.112990048440, -0.481086916514,
			            0.126598690230, -0.015510730165,
				    0.000024609059 - 0.000003,
			            0.000156447571 - 0.000000000001,
				    -0.000007390277},
			           {0., 0.057982271137, -0.536135360383,
			            -0.264089548969, 0.917445877604,
			            -0.169688364841, -0.029716326170,
				    0.029681617641, -0.005222483773,
				    -0.000118806260, -0.000118806260,
			            -0.000020069730},
			           {0., -0.013277273810, 0.115976072920,
				    -0.617479187931, -0.274113948206 + 0.000000000002,
			            1.086208764655 - 0.000000000002,
			            -0.402951626982, 0.131066986242,
				    -0.028154858354, 0.002596328316,
				    0.000128743150, 0.},
			           {0., 0.016756572303, -0.117478455239,
				    0.411034935097, -1.130286765151,
				    0.341435872100 - 0.000000000001, 0.556396830543,
				    -0.082525734207, 0.003565834658,
			            0.001173034777, -0.000071772671 + 0.000000000064,
			            -0.000000352273}};

static const double d11d[6][12] = {{0.},
				   {0., 0.320882352941, -0.465,
			            0.179117647059, -0.035},
				   {0., -0.085777408970 + 0.000000000001,
				    0.277628171524, -0.356848072173,
				    0.223119093072, -0.057347064865,
				    -0.000747264596, -0.000027453993},
				   {0., 0.0307159855992469, -0.148395705486028,
				    0.312055385963757, -0.363202245195514,
				    0.230145457063431, -0.0412316564605079,
				    -0.0531024700805787, 0.0494343261171287,
				    -0.0198143585458560, 0.00339528102492129},
				   {0., -0.000054596010, 0.042124772446,
				    -0.173103107841, 0.299615871352,
				    -0.276543612935, 0.131223506571,
				    -0.023424966418, 0.013937561779,
				    -0.024565095706, 0.013098287852,
				    -0.002308621090},
				   {0., 0.008391235145, -0.047402506444,
				    0.121438547725, -0.200063042812,
				    0.240069047836, -0.207269200140 - 0.000000000001,
				     0.122263107844 - 0.000000000001,
				     -0.047121062819, 0.009014891495,
				     0.001855812216, -0.001176830044}
				   };

static const double d11c[6] = {0.234810479761700, -0.199250131285813,
			       0.120198310245186, -0.049303775636020,
			       0.012396449873964, -0.001446093078167};

static const double d3c[2] = {0.5, -0.25};

static const double d5c[3] = {0.375, -0.25, 0.0625};

static const double d7c[4] = {0.2873928425, -0.2261469518, 0.1063035788, -0.0238530482};

static const double c_sc[4] = {0.210383, -0.210383, 0.039617, -0.039617};

static const double eps = 6e-8;

//static const double g1 = 1.0000000000000000;
//static const double g2 = 0.5000000000000000;
//static const double g3 = 0.1659197713678104;
//static const double g4 = 4.091973204095216e-2;
//static const double g5 = 7.555704391128985e-3;
//static const double g6 = 8.914212608018190e-4;

//static const double r6 = g1;
//static const double r5 = g2;
//static const double r4 = g3/r5;
//static const double r3 = g4/(r4*r5);
//static const double r2 = g5/(r3*r4*r5);
//static const double r1 = g6/(r2*r3*r4*r5);

//static const double rk[7] = {0., r1, r2, r3, r4, r5, r6};

static const double rk[7] = {0., 0.1179799016288171, 0.1846469664944847, 
                             0.24662360430958788, 0.3318395427356208,  0.5, 1.};
